==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGeoProjectionSource.java <==
// java wrapper for vtkGeoProjectionSource object
//

package vtk;
import vtk.*;

public class vtkGeoProjectionSource extends vtkGeoSource
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean FetchRoot_2(vtkGeoTreeNode id0);
  public boolean FetchRoot(vtkGeoTreeNode id0)
    { return FetchRoot_2(id0); }

  private native boolean FetchChild_3(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2);
  public boolean FetchChild(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2)
    { return FetchChild_3(id0,id1,id2); }

  private native int GetProjection_4();
  public int GetProjection()
    { return GetProjection_4(); }

  private native void SetProjection_5(int id0);
  public void SetProjection(int id0)
    { SetProjection_5(id0); }

  private native int GetMinCellsPerNode_6();
  public int GetMinCellsPerNode()
    { return GetMinCellsPerNode_6(); }

  private native void SetMinCellsPerNode_7(int id0);
  public void SetMinCellsPerNode(int id0)
    { SetMinCellsPerNode_7(id0); }

  private native long GetTransform_8();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_8();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGeoProjectionSource() { super(); }

  public vtkGeoProjectionSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv7h.pkg.tar.xz: vtk/vtkGeoProjectionSource.java <==
// java wrapper for vtkGeoProjectionSource object
//

package vtk;
import vtk.*;

public class vtkGeoProjectionSource extends vtkGeoSource
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean FetchRoot_2(vtkGeoTreeNode id0);
  public boolean FetchRoot(vtkGeoTreeNode id0)
    { return FetchRoot_2(id0); }

  private native boolean FetchChild_3(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2);
  public boolean FetchChild(vtkGeoTreeNode id0,int id1,vtkGeoTreeNode id2)
    { return FetchChild_3(id0,id1,id2); }

  private native int GetProjection_4();
  public int GetProjection()
    { return GetProjection_4(); }

  private native void SetProjection_5(int id0);
  public void SetProjection(int id0)
    { SetProjection_5(id0); }

  private native int GetMinCellsPerNode_6();
  public int GetMinCellsPerNode()
    { return GetMinCellsPerNode_6(); }

  private native void SetMinCellsPerNode_7(int id0);
  public void SetMinCellsPerNode(int id0)
    { SetMinCellsPerNode_7(id0); }

  private native long GetTransform_8();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_8();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGeoProjectionSource() { super(); }

  public vtkGeoProjectionSource(long id) { super(id); }
  public native long   VTKInit();

}
